==> kvirc-trinity_3.5.13.2.orig.tar.xz: kvirc-trinity-3.5.13.2/src/modules/dockwidget/libkvidockwidget_qt3.h <==
#ifndef _KVI_DOCKWIDGET_H_
#define _KVI_DOCKWIDGET_H_
//
//   This file is part of the KVirc irc client distribution
//   Creation date : Tue 02 Jan 2001 14:28:25 by Szymon Stefanek
//   Copyright (C) 2000-2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//


#include "kvi_frame.h"

#ifdef COMPILE_KDE_SUPPORT
	class KPopupMenu;
#else
	class KviTalPopupMenu;
#endif




class TQPixmap;
class TQTimer;

//class KviFrame;
class KviDynamicToolTip;

class KviDockWidget : public TQWidget , public KviDockExtension
{
	Q_OBJECT
  TQ_OBJECT
public:
	KviDockWidget(KviFrame * win,const char * name);
	~KviDockWidget();
protected:
	KviFrame          * m_pFrm;
	KviDynamicToolTip * m_pTip;
#ifdef COMPILE_KDE_SUPPORT
	KPopupMenu        * m_pContextPopup;
#else
	KviTalPopupMenu        * m_pContextPopup;
#endif
	KviTalPopupMenu        * m_pAwayPopup;
	int m_iToggleFrame;
	int m_iAwayMenuId;

	bool m_bFlashed;
	
	TQTimer* m_pFlashingTimer;
	int m_iConsoles;
	int m_iChannels;
	int m_iQueries;
	int m_iOther;
public:
	KviFrame * frame(){ return m_pFrm; };
public:
//	virtual int message(int msgtype,void * data);
	virtual void enterEvent(TQEvent *);
	virtual void refresh();
	virtual void die();
protected:
	virtual void paintEvent(TQPaintEvent *e);
	virtual void mousePressEvent(TQMouseEvent *e);
	void grabActivityInfo();

#ifdef COMPILE_ON_WINDOWS
private:
	void createTaskbarIcon();
	void destroyTaskbarIcon();
	void updateTaskbarIcon();
protected:
	bool winEvent(MSG * m);
#endif

protected slots:
	void fillContextPopup();
	void toggleParentFrame();
	void tipRequest(KviDynamicToolTip *tip,const TQPoint &pnt);
	void doAway(int);
	void flashingTimerShot();
};

#endif //_KVI_DOCKWIDGET_H_

==> kvirc-trinity-14.0.13.tar.xz: kvirc-trinity-14.0.13/src/modules/dockwidget/libkvidockwidget_qt3.h <==
#ifndef _KVI_DOCKWIDGET_H_
#define _KVI_DOCKWIDGET_H_
//
//   This file is part of the KVirc irc client distribution
//   Creation date : Tue 02 Jan 2001 14:28:25 by Szymon Stefanek
//   Copyright (C) 2000-2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//


#include "kvi_frame.h"

#ifdef COMPILE_TDE_SUPPORT
	class TDEPopupMenu;
#else
	class KviTalPopupMenu;
#endif




class TQPixmap;
class TQTimer;

//class KviFrame;
class KviDynamicToolTip;

class KviDockWidget : public TQWidget , public KviDockExtension
{
	Q_OBJECT
  
public:
	KviDockWidget(KviFrame * win,const char * name);
	~KviDockWidget();
protected:
	KviFrame          * m_pFrm;
	KviDynamicToolTip * m_pTip;
#ifdef COMPILE_TDE_SUPPORT
	TDEPopupMenu        * m_pContextPopup;
#else
	KviTalPopupMenu        * m_pContextPopup;
#endif
	KviTalPopupMenu        * m_pAwayPopup;
	int m_iToggleFrame;
	int m_iAwayMenuId;

	bool m_bFlashed;
	
	TQTimer* m_pFlashingTimer;
	int m_iConsoles;
	int m_iChannels;
	int m_iQueries;
	int m_iOther;
public:
	KviFrame * frame(){ return m_pFrm; };
public:
//	virtual int message(int msgtype,void * data);
	virtual void enterEvent(TQEvent *);
	virtual void refresh();
	virtual void die();
protected:
	virtual void paintEvent(TQPaintEvent *e);
	virtual void mousePressEvent(TQMouseEvent *e);
	void grabActivityInfo();

#ifdef COMPILE_ON_WINDOWS
private:
	void createTaskbarIcon();
	void destroyTaskbarIcon();
	void updateTaskbarIcon();
protected:
	bool winEvent(MSG * m);
#endif

protected slots:
	void fillContextPopup();
	void toggleParentFrame();
	void tipRequest(KviDynamicToolTip *tip,const TQPoint &pnt);
	void doAway(int);
	void flashingTimerShot();
};

#endif //_KVI_DOCKWIDGET_H_
